@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-13 10:00:12
+@LastEditTime: 2022-07-13 11:27:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,8 +10,8 @@ from seven_cloudapp.handlers.seven_base import *
 from seven_cloudapp.handlers.top_base import *
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
-from seven_cloudapp_ppmt.db_models.launch.launch_plan_model import *
-from seven_cloudapp_ppmt.db_models.launch.launch_goods_model import *
+from seven_cloudapp_ppmt.models.db_models.launch.launch_plan_model import *
+from seven_cloudapp_ppmt.models.db_models.launch.launch_goods_model import *
 
 
 class InitLaunchGoodsHandler(SevenBaseHandler):
@@ -310,7 +310,7 @@ class AsyncLaunchGoodsHandler(TopBaseHandler):
                 if len(launch_goods) > 0:
                     if async_result_info["success"] == True:
                         launch_goods[0].is_sync = 1
-                        launch_goods[0].sync_date = SevenHelper.get_now_datetime()
+                        launch_goods[0].sync_date = self.get_now_datetime()
                     else:
                         launch_goods[0].is_launch = 0
                         launch_goods[0].is_sync = 1
@@ -491,8 +491,8 @@ class CanLaunchGoodsListHandler(TopBaseHandler):
                 goods["is_select"] = 0
                 goods["bind_act_id"] = 0
                 goods["bind_act_name"] = ""
-                
-                
+
+
         return self.reponse_json_success(resp)
 
 
